==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/zh2/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(列表 新的) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "把:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " 和:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "系列 新的 "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "系列 ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL              "空虚"
#define CTR_DICT_BOOLEAN          "布尔型"
#define CTR_DICT_TRUE             "真正"
#define CTR_DICT_FALSE            "假"
#define CTR_DICT_NUMBER           "数"
#define CTR_DICT_STRING           "文本"
#define CTR_DICT_TASK             "码"
#define CTR_DICT_OBJECT           "物体"
#define CTR_DICT_ARRAY_OBJECT     "系列"
#define CTR_DICT_MAP_OBJECT       "列表"
#define CTR_DICT_PROGRAM          "程序"
#define CTR_DICT_FILE             "文件"
#define CTR_DICT_MOMENT           "时刻"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "新的"
#define CTR_DICT_EQUALS           "等于:"
#define CTR_DICT_AND              "和:"
#define CTR_DICT_OR               "要么:"
#define CTR_DICT_MODULO           "模数:"
#define CTR_DICT_NOR              "也不:"
#define CTR_DICT_ONDO             "上:做:"
#define CTR_DICT_TYPE             "类型"
#define CTR_DICT_ISNIL            "是空的？"
#define CTR_DICT_MYSELF           "你自己"
#define CTR_DICT_DO               "一系列消息"
#define CTR_DICT_DONE             "做完了"
#define CTR_DICT_IFFALSE          "假:"
#define CTR_DICT_IFTRUE           "真:"
#define CTR_DICT_WHILE            "而:"
#define CTR_DICT_MESSAGEARGS      "消息:参数:"
#define CTR_DICT_MESSAGE          "信息:"
#define CTR_DICT_LEARN            "学习:表示:"
#define CTR_DICT_BREAK            "打破"
#define CTR_DICT_CONTINUE         "继续"
#define CTR_DICT_ELSE             "其他:"
#define CTR_DICT_NOT              "相反的"
#define CTR_DICT_TONUMBER         "编号"
#define CTR_DICT_ITONUMBER        "国际号码"
#define CTR_DICT_TOSTRING         "做一个文本"
#define CTR_DICT_CHAR_AT_SET      "字符:"
#define CTR_DICT_EITHEROR         "这两个:或之一:"
#define CTR_DICT_BY_SET           "通过:"
#define CTR_DICT_FLOOR            "收缩"
#define CTR_DICT_CEIL             "向上"
#define CTR_DICT_ROUND            "圓形"
#define CTR_DICT_ABS              "绝对"
#define CTR_DICT_SQRT             "平方根"
#define CTR_DICT_POWER            "求幂:"
#define CTR_DICT_MIN              "最低"
#define CTR_DICT_MAX              "最大值"
#define CTR_DICT_ODD              "一个奇数？"
#define CTR_DICT_EVEN             "偶数？"
#define CTR_DICT_POS              "正？"
#define CTR_DICT_NEG              "负？"
#define CTR_DICT_TOBOOL           "布尔值"
#define CTR_DICT_RANDOM_NUM_BETWEEN "给出一个:到之间的随机数:"
#define CTR_DICT_LENGTH	          "长度"
#define CTR_DICT_FROM_LENGTH	  "来自:长度:"
#define CTR_DICT_TRIM	          "删除周围的空间"
#define CTR_DICT_AT               "在:"
#define CTR_DICT_POSITION_SET     "位置:"
#define CTR_DICT_INDEX_OF         "找:"
#define CTR_DICT_LAST_INDEX_OF	  "持续:"
#define CTR_DICT_REPLACE_WITH	  "用:来代替:"
#define CTR_DICT_SPLIT	          "分裂:"
#define CTR_DICT_SKIP             "抵消:"
#define CTR_DICT_RUN              "开始"
#define CTR_DICT_APPLY_TO         "将逻辑应用于:"
#define CTR_DICT_APPLY_TO_AND     "将逻辑应用于:和:"
#define CTR_DICT_VALUE_SET        "设定:值:"
#define CTR_DICT_ERROR	          "错误:"
#define CTR_DICT_CATCH            "抓住:"
#define CTR_DICT_PUSH_SYMBOL      ";"
#define CTR_DICT_SHIFT            "底部元素"
#define CTR_DICT_COUNT            "计数"
#define CTR_DICT_JOIN             "加入:"
#define CTR_DICT_POP              "顶部元素"
#define CTR_DICT_SORT             "分类:"
#define CTR_DICT_PUT_AT           "把:和:"
#define CTR_DICT_MAP              "列表:"
#define CTR_DICT_EACH             "每:"
#define CTR_DICT_WRITE            "写:"
#define CTR_DICT_PATH             "路径"
#define CTR_DICT_READ             "读取数据"
#define CTR_DICT_APPEND           "附加:"
#define CTR_DICT_PREPEND          "前置:"
#define CTR_DICT_EXISTS           "存在"
#define CTR_DICT_SIZE             "尺寸"
#define CTR_DICT_DELETE           "删除"
#define CTR_DICT_USE_SET          "采用:"
#define CTR_DICT_ARRAY             "系列:"
#define CTR_DICT_END              "结束"
#define CTR_DICT_ARGUMENT	      "参数:"
#define CTR_DICT_ARGUMENT_COUNT	  "论点"
#define CTR_DICT_WAIT_FOR_PASSW	  "問密碼"
#define CTR_DICT_WAIT_FOR_INPUT	  "问一个问题"
#define CTR_DICT_INPUT            "输入"
#define CTR_DICT_FLUSH            "齐平"
#define CTR_DICT_WAIT             "等待:"
#define CTR_DICT_TIME             "时间"
#define CTR_DICT_RESPOND_TO       "反应:"
#define CTR_DICT_RESPOND_TO_AND   "反应:和:"
#define CTR_DICT_SHELL            "系统命令:"
#define CTR_DICT_SWEEP            "干净的内存"
#define CTR_DICT_MEMORY_LIMIT     "记忆:"
#define CTR_DICT_MEMORY           "记忆"
#define CTR_DICT_GC_MODE           "整洁度:"
#define CTR_DICT_HASH_WITH_KEY    "杂凑:"
#define CTR_DICT_CHARACTERS       "人物"
#define CTR_DICT_QUALIFIER_SET    "特征:"
#define CTR_DICT_QUALIFIER        "特征"
#define CTR_DICT_NEW_SET          "新的:"
#define CTR_DICT_HOUR             "小时"
#define CTR_DICT_HOUR_SET         "小时:"
#define CTR_DICT_MINUTE_SET       "分钟:"
#define CTR_DICT_MINUTE           "分钟"
#define CTR_DICT_SECOND_SET       "第二:"
#define CTR_DICT_SECOND           "第二"
#define CTR_DICT_DAY              "哪天"
#define CTR_DICT_DAY_SET          "天:"
#define CTR_DICT_WEEK             "哪周"
#define CTR_DICT_WEEK_SET         "周:"
#define CTR_DICT_MONTH            "哪月"
#define CTR_DICT_MONTH_SET        "月:"
#define CTR_DICT_YEAR             "哪年"
#define CTR_DICT_RAW              "生的"
#define CTR_DICT_YEAR_SET         "年:"
#define CTR_DICT_WEEK_DAY         "平日"
#define CTR_DICT_YEAR_DAY         "一年中的一天"
#define CTR_DICT_ZONE             "哪区"
#define CTR_DICT_ZONE_SET         "区:"
#define CTR_DICT_ADD_SET          "加:"
#define CTR_DICT_SUBTRACT_SET     "减去:"
#define CTR_DICT_MULTIPLIER_SET   "乘以:"
#define CTR_DICT_DIVIDER_SET      "被除以:"
#define CTR_DICT_LAST             "持续"
#define CTR_DICT_FIRST            "第一"
#define CTR_DICT_SECOND_LAST      "最后第二"
#define CTR_DICT_FILL_WITH        "数量:馅:"
#define CTR_DICT_SPLICE           "用:替换:长度:"
#define CTR_DICT_VALUES           "价值观"
#define CTR_DICT_ENTRIES          "参赛作品"
#define CTR_DICT_COMPARE_SET      "比较:"
#define CTR_DICT_HAS              "已:"
#define CTR_DICT_COPY             "复制"
#define CTR_DICT_CASE_DO          "案例:做:"
#define CTR_DICT_STOP             "句末"
#define CTR_DICT_ASCII_UPPER_CASE                 "大写"
#define CTR_DICT_ASCII_LOWER_CASE                 "小写"
#define CTR_DICT_CONTAINS                         "包含:"
#define CTR_DICT_APPLY_TO_AND_AND                 "将逻辑应用于:和:和:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "设置:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "设置:值:"
#define CTR_DICT_RESPOND_TO_AND_AND               "反应:和:和:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "反应:和:和:和:"
#define CTR_DICT_CURRENT_TASK                     "此代码块"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "“"
#define CTR_DICT_QUOT_CLOSE                      "”"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "程序代码"
#define CTR_DICT_PROCEDURE                       "决定"
#define CTR_DICT_TOOBJECT        "作为对象"
#define CTR_DICT_PATH_OBJECT "档案位置"
#define CTR_DICT_CMD_OBJECT  "指令"
#define CTR_DICT_RECURSIVE "递归的"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/zh2/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(列表 新的) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "把:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " 和:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "系列 新的 "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "系列 ← "
#define CTR_DICT_END_OF_LINE     "。"
#define CTR_DICT_NIL              "空虚"
#define CTR_DICT_BOOLEAN          "布尔型"
#define CTR_DICT_TRUE             "真正"
#define CTR_DICT_FALSE            "假"
#define CTR_DICT_NUMBER           "数"
#define CTR_DICT_STRING           "文本"
#define CTR_DICT_TASK             "码"
#define CTR_DICT_OBJECT           "物体"
#define CTR_DICT_ARRAY_OBJECT     "系列"
#define CTR_DICT_MAP_OBJECT       "列表"
#define CTR_DICT_PROGRAM          "程序"
#define CTR_DICT_FILE             "文件"
#define CTR_DICT_MOMENT           "时刻"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "新的"
#define CTR_DICT_EQUALS           "等于:"
#define CTR_DICT_AND              "和:"
#define CTR_DICT_OR               "要么:"
#define CTR_DICT_MODULO           "模数:"
#define CTR_DICT_NOR              "也不:"
#define CTR_DICT_ONDO             "上:做:"
#define CTR_DICT_TYPE             "类型"
#define CTR_DICT_ISNIL            "是空的？"
#define CTR_DICT_MYSELF           "你自己"
#define CTR_DICT_DO               "一系列消息"
#define CTR_DICT_DONE             "做完了"
#define CTR_DICT_IFFALSE          "假:"
#define CTR_DICT_IFTRUE           "真:"
#define CTR_DICT_WHILE            "而:"
#define CTR_DICT_MESSAGEARGS      "消息:参数:"
#define CTR_DICT_MESSAGE          "信息:"
#define CTR_DICT_LEARN            "学习:表示:"
#define CTR_DICT_BREAK            "打破"
#define CTR_DICT_CONTINUE         "继续"
#define CTR_DICT_ELSE             "其他:"
#define CTR_DICT_NOT              "相反的"
#define CTR_DICT_TONUMBER         "编号"
#define CTR_DICT_ITONUMBER        "国际号码"
#define CTR_DICT_TOSTRING         "做一个文本"
#define CTR_DICT_CHAR_AT_SET      "字符:"
#define CTR_DICT_EITHEROR         "或者:或者:"
#define CTR_DICT_BY_SET           "按:"
#define CTR_DICT_FLOOR            "向下取整"
#define CTR_DICT_CEIL             "向上取整"
#define CTR_DICT_ROUND            "四舍五入"
#define CTR_DICT_ABS              "绝对值"
#define CTR_DICT_SQRT             "平方根"
#define CTR_DICT_POWER            "求幂:"
#define CTR_DICT_MIN              "最低"
#define CTR_DICT_MAX              "最大值"
#define CTR_DICT_ODD              "一个奇数？"
#define CTR_DICT_EVEN             "偶数？"
#define CTR_DICT_POS              "正？"
#define CTR_DICT_NEG              "负？"
#define CTR_DICT_TOBOOL           "布尔值"
#define CTR_DICT_RANDOM_NUM_BETWEEN "给出一个:到之间的随机数:"
#define CTR_DICT_LENGTH	          "长度"
#define CTR_DICT_FROM_LENGTH	  "来自:长度:"
#define CTR_DICT_TRIM	          "删除周围的空间"
#define CTR_DICT_AT               "在:"
#define CTR_DICT_POSITION_SET     "位置:"
#define CTR_DICT_INDEX_OF         "找:"
#define CTR_DICT_LAST_INDEX_OF	  "持续:"
#define CTR_DICT_REPLACE_WITH	  "用:来代替:"
#define CTR_DICT_SPLIT	          "分裂:"
#define CTR_DICT_SKIP             "抵消:"
#define CTR_DICT_RUN              "开始"
#define CTR_DICT_APPLY_TO         "将逻辑应用于:"
#define CTR_DICT_APPLY_TO_AND     "将逻辑应用于:和:"
#define CTR_DICT_VALUE_SET        "设定:值:"
#define CTR_DICT_ERROR	          "错误:"
#define CTR_DICT_CATCH            "抓住:"
#define CTR_DICT_PUSH_SYMBOL      ";"
#define CTR_DICT_SHIFT            "底部元素"
#define CTR_DICT_COUNT            "计数"
#define CTR_DICT_JOIN             "加入:"
#define CTR_DICT_POP              "顶部元素"
#define CTR_DICT_SORT             "分类:"
#define CTR_DICT_PUT_AT           "把:和:"
#define CTR_DICT_MAP              "列表:"
#define CTR_DICT_EACH             "每:"
#define CTR_DICT_WRITE            "写入:"
#define CTR_DICT_PATH             "路径"
#define CTR_DICT_READ             "读取数据"
#define CTR_DICT_APPEND           "附加:"
#define CTR_DICT_PREPEND          "前置:"
#define CTR_DICT_EXISTS           "存在"
#define CTR_DICT_SIZE             "尺寸"
#define CTR_DICT_DELETE           "删除"
#define CTR_DICT_USE_SET          "采用:"
#define CTR_DICT_ARRAY             "系列:"
#define CTR_DICT_END              "结束"
#define CTR_DICT_ARGUMENT	      "参数:"
#define CTR_DICT_ARGUMENT_COUNT	  "论点"
#define CTR_DICT_WAIT_FOR_PASSW	  "問密碼"
#define CTR_DICT_WAIT_FOR_INPUT	  "问一个问题"
#define CTR_DICT_INPUT            "输入"
#define CTR_DICT_FLUSH            "齐平"
#define CTR_DICT_WAIT             "等待:"
#define CTR_DICT_TIME             "时间"
#define CTR_DICT_RESPOND_TO       "反应:"
#define CTR_DICT_RESPOND_TO_AND   "反应:和:"
#define CTR_DICT_SHELL            "系统命令:"
#define CTR_DICT_SWEEP            "干净的内存"
#define CTR_DICT_MEMORY_LIMIT     "记忆:"
#define CTR_DICT_MEMORY           "记忆"
#define CTR_DICT_GC_MODE           "整洁度:"
#define CTR_DICT_HASH_WITH_KEY    "杂凑:"
#define CTR_DICT_CHARACTERS       "人物"
#define CTR_DICT_QUALIFIER_SET    "特征:"
#define CTR_DICT_QUALIFIER        "特征"
#define CTR_DICT_NEW_SET          "新的:"
#define CTR_DICT_HOUR             "小时"
#define CTR_DICT_HOUR_SET         "小时:"
#define CTR_DICT_MINUTE_SET       "分钟:"
#define CTR_DICT_MINUTE           "分钟"
#define CTR_DICT_SECOND_SET       "第二:"
#define CTR_DICT_SECOND           "第二"
#define CTR_DICT_DAY              "哪天"
#define CTR_DICT_DAY_SET          "天:"
#define CTR_DICT_WEEK             "星期"
#define CTR_DICT_WEEK_SET         "星期:"
#define CTR_DICT_MONTH            "月份"
#define CTR_DICT_MONTH_SET        "月份:"
#define CTR_DICT_YEAR             "哪年"
#define CTR_DICT_RAW              "原始"
#define CTR_DICT_YEAR_SET         "年:"
#define CTR_DICT_WEEK_DAY         "平日"
#define CTR_DICT_YEAR_DAY         "一年中的一天"
#define CTR_DICT_ZONE             "时区"
#define CTR_DICT_ZONE_SET         "时区:"
#define CTR_DICT_ADD_SET          "加:"
#define CTR_DICT_SUBTRACT_SET     "减:"
#define CTR_DICT_MULTIPLIER_SET   "乘:"
#define CTR_DICT_DIVIDER_SET      "除:"
#define CTR_DICT_LAST             "最后"
#define CTR_DICT_FIRST            "首个"
#define CTR_DICT_SECOND_LAST      "倒数第二个"
#define CTR_DICT_FILL_WITH        "填充:用:"
#define CTR_DICT_SPLICE           "替换:长度:用:"
#define CTR_DICT_VALUES           "价值观"
#define CTR_DICT_ENTRIES          "条目"
#define CTR_DICT_COMPARE_SET      "比较:"
#define CTR_DICT_HAS              "已:"
#define CTR_DICT_COPY             "复制"
#define CTR_DICT_CASE_DO          "案例:做:"
#define CTR_DICT_STOP             "停止"
#define CTR_DICT_ASCII_UPPER_CASE                 "大写"
#define CTR_DICT_ASCII_LOWER_CASE                 "小写"
#define CTR_DICT_CONTAINS                         "包含:"
#define CTR_DICT_APPLY_TO_AND_AND                 "将逻辑应用于:和:和:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "设置:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "设置:值:"
#define CTR_DICT_RESPOND_TO_AND_AND               "反应:和:和:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "反应:和:和:和:"
#define CTR_DICT_CURRENT_TASK                     "当前代码块"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "“"
#define CTR_DICT_QUOT_CLOSE                      "”"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "程序代码"
#define CTR_DICT_PROCEDURE                       "决定"
#define CTR_DICT_TOOBJECT        "作为对象"
#define CTR_DICT_PATH_OBJECT "档案位置"
#define CTR_DICT_CMD_OBJECT  "命令"
#define CTR_DICT_RECURSIVE "递归"
